referrerpolicy=no-referrer-when-downgrade

WaivedLocations

Type Alias WaivedLocations 

pub type WaivedLocations = (SystemParachains, Equals<RootLocation>, LocalPlurality);
Locations that will not be charged fees in the executor, neither for execution nor delivery. We only waive fees for system functions, which these locations represent.